*using Stata 12; use data file "MavesBraith_JOP_data10.dta" for use with Stata 9 or 10.

use "/Users/jamaves/Desktop/MavesBraith_JOP_contagion/MavesBraith_JOP_data.dta"

***************************************
**** TABLE AND FIGURE FROM ARTICLE ****
***************************************

**** TABLE 1 ****
**Model 1: continuous measure, autocracies
probit onset2cv410 ndlegele neighall_autocs ndlegxneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=., nolog vce(cluster ccode)
predict phat_n_a
**Model 2: binary measure, autocracies
probit onset2cv410 ndlegele neighall_b_autocs ndlegxneighall_b_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
predict phat_n_b_a
**Model 3: structural equiv./Gower, autocracies
probit onset2cv410 ndlegele autoc_gower ndlegxagower neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
predict phat_a_g


**** FIGURE 1 ****
twoway (spike y5 neighall_autocs, base(-0.0005))(qfitci phat_n_a neighall_autocs if ndlegele==0, yaxis(1) clcolor(black) clwidth(medium) clpattern(dash) ciplot(rline) blwidth(vthin) blpattern(solid)) (qfitci phat_n_a ndlegxneighall_autocs, yaxis(1) clcolor(black) clwidth(medium) clpattern(solid) ciplot(rline) blwidth(vthin) blpattern(solid)), ytitle(Pr(civil war onset)) xtitle(Neighborhood Conflict (Continuous Measure)) graphregion(fcolor(white)) legend(order(3 "autocracies without legislatures" 4 "95% confidence intervals" 5 "autocracies with legislatures"))


**
**
**
**


*************************************************
**** TABLES AND FIGURES FROM ONLINE APPENDIX ****
*************************************************

**** Table 1: descriptive statistics ****
sum onset2cv410 ndlegele neighall_autocs neighall_b_autocs autoc_gower ndlegele_gower neighall neighall_b ndlegxneighall_autocs ndlegxneighall_b_autocs ndlegxagower ndlegxndgower ndlegxneighall ndlegxneighall_b neighbor_cg_democracy neighbor_legele lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed military monarch inherit cg_stra


**** Table 2: bivariate probit ****
**Model 1: continuous measure, autocracies
biprobit (outcome: onset2cv410 = ndlegele neighall_autoc ndlegxneighall_autoc neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed)(selection: ndlegele = neighall_autoc neighbor_legele military monarch inherit cg_stra post peaceyrs_onset) if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., vce(cluster ccode) 
**Model 2: binary measure, autocracies
biprobit (outcome: onset2cv410 = ndlegele neighall_b_autocs ndlegxneighall_b_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed)(selection: ndlegele = neighall_b_autocs neighbor_legele military monarch inherit cg_stra post peaceyrs_onset) if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., vce(cluster ccode) 
**Model 3: structural equiv./Gower Distance, autocracies
biprobit (outcome: onset2cv410 = ndlegele autoc_gower ndlegxagower neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed)(selection: ndlegele = autoc_gower neighbor_legele military monarch inherit cg_stra post peaceyrs_onset) if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., vce(cluster ccode) 
**Model 4: structural equiv./Gower Distance, autocracies w/legislatures
biprobit (outcome: onset2cv410 = ndlegele ndlegele_gower ndlegxndgower neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed)(selection: ndlegele = ndlegele_gower neighbor_legele military monarch inherit cg_stra post peaceyrs_onset) if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., vce(cluster ccode) 


**** Table 3: global sample ****
**Model 1: continuous measure, all countries
probit onset2cv410 ndlegele neighall ndlegxneighall neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall_autocs~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 2: binary measure, all countries
probit onset2cv410 ndlegele neighall_b ndlegxneighall_b neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)


**** Table 4: new vs. old legislatures, all autocracies ****
**Model 1: legislature introduced in last 1 year
probit onset2cv410 newlegele neighall_autocs newlegxneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0  & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 2: legislature introduced in last 2 years
probit onset2cv410 newlegele2 neighall_autocs newleg2xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 3: legislature introduced in last 3 years
probit onset2cv410 newlegele3 neighall_autocs newleg3xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 4: legislature introduced in last 4 years
probit onset2cv410 newlegele4 neighall_autocs newleg4xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 5: legislature introduced in last 5 years
probit onset2cv410 newlegele5 neighall_autocs newleg5xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)


**** Table 5: new vs. old legislatures, only autocracies with legislatures ****
**Model 1: legislature introduced in last 1 year
probit onset2cv410 newlegele neighall_autocs newlegxneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if ndlegele==1 & democracy==0  & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 2: legislature introduced in last 2 years
probit onset2cv410 newlegele2 neighall_autocs newleg2xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if ndlegele==1 & democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 3: legislature introduced in last 3 years
probit onset2cv410 newlegele3 neighall_autocs newleg3xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if ndlegele==1 & democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 4: legislature introduced in last 4 years
probit onset2cv410 newlegele4 neighall_autocs newleg4xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if ndlegele==1 & democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 5: legislature introduced in last 5 years
probit onset2cv410 newlegele5 neighall_autocs newleg5xneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if ndlegele==1 & democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)


**** Table 6: legislatures in the neighborhood ****
**Model 1: continuous measure, autocracies
probit onset2cv410 ndlegele neighall_autocs ndlegxneighall_autocs neighbor_legele lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=., nolog vce(cluster ccode)
**Model 2: binary measure, autocracies
probit onset2cv410 ndlegele neighall_b_autocs ndlegxneighall_b_autocs neighbor_legele lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 3: structural equiv./gower distance, autocracies
probit onset2cv410 ndlegele autoc_gower ndlegxagower neighbor_legele lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**Model 4: structural equiv./gower distance, autocracies w/legislatures only
probit onset2cv410 ndlegele ndlegele_gower ndlegxndgower neighbor_legele lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)


**** Table 7: strucutral equivalence, autocratic legislatures ****
**Model 1: structural equiv./gower distance, autocracies w/legislatures only -- neighborhood democracy variable
probit onset2cv410 ndlegele ndlegele_gower ndlegxndgower neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)


**** Figure 1: predicted probability of onset as neighborhood conflict (structural equiv.) changes ****
twoway (spike y4 autoc_gower, base(-0.0005))(qfitci phat_a_g autoc_gower if ndlegele==0, clcolor(black) clwidth(medium) clpattern(dash) ciplot(rline) blwidth(vthin) blpattern(solid)) (qfitci phat_a_g ndlegxagower, clcolor(black) clwidth(medium) clpattern(solid) ciplot(rline) blwidth(vthin) blpattern(solid)), ytitle(Pr(civil war onset)) xtitle(Proportion of autocracies experiencing civil wars) legend(order(3 "autocracies without legislatures" 4 "95% confidence intervals" 5 "autocracies with legislatures"))


**** Table 8: models without interaction term ****
**Model 1: continuous measure, autocracies
probit onset2cv410 ndlegele neighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**MODEL 2: binary measure, autocracies
probit onset2cv410 ndlegele neighall_b_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
**MODEL 3: structural equiv./gower distance, autocracies
probit onset2cv410 ndlegele autoc_gower neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)


**
**
**
**

*****************************************************************************
**** PREDICTED PROBABILITIES based on models from Table 1 in the article ****
*****************************************************************************

**MODEL 1: neighall_autocs=mean->mean+SD
estsimp probit onset2cv410 ndlegele neighall_autocs ndlegxneighall_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
setx ndlegxneighall_autocs 0.126 ndlegele 1 neighall_autocs 0.126 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.341 ndlegele 1 neighall_autocs 0.341 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
**MODEL 1: ndlegele=0->1
*neighall_autocs @ 25th percentile
setx ndlegxneighall_autocs 0 ndlegele 0 neighall_autocs .002 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.002 ndlegele 1 neighall_autocs .002 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
*neighall_autocs @ 50th percentile
setx ndlegxneighall_autocs 0 ndlegele 0 neighall_autocs .027 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.027 ndlegele 1 neighall_autocs .027 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
*neighall_autocs @ 75th percentile
setx ndlegxneighall_autocs 0 ndlegele 0 neighall_autocs .324 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.324 ndlegele 1 neighall_autocs .324 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
*CHANGES HERE
setx ndlegxneighall_autocs 0 ndlegele 0 neighall_autocs .475 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.475 ndlegele 1 neighall_autocs .475 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
*neighall_autocs @ 90th percentile
setx ndlegxneighall_autocs 0 ndlegele 0 neighall_autocs .498 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.498 ndlegele 1 neighall_autocs .498 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
*neighall_autocs @ 95th percentile
setx ndlegxneighall_autocs 0 ndlegele 0 neighall_autocs .704 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_autocs 0.704 ndlegele 1 neighall_autocs .704 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11

**MODEL 2: neighall_b_autocs=mean->mean+SD
estsimp probit onset2cv410 ndlegele neighall_b_autocs ndlegxneighall_b_autocs neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
setx ndlegxneighall_b_autocs 0 ndlegele 1 neighall_b_autocs 0 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_b_autocs 1 ndlegele 1 neighall_b_autocs 1 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
**MODEL 2: ndlegele=0->1
* neighall_b_autocs=0
setx ndlegxneighall_b_autocs 0 ndlegele 0 neighall_b_autocs 0 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_b_autocs 0 ndlegele 1 neighall_b_autocs 0 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
* neighall_b_autocs=1
setx ndlegxneighall_b_autocs 0 ndlegele 0 neighall_b_autocs 1 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxneighall_b_autocs 1 ndlegele 1 neighall_b_autocs 1 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11

**MODEL 3: autoc_gower=mean->mean+SD
estsimp probit onset2cv410 ndlegele autoc_gower ndlegxagower neighbor_cg_democracy lnlgdppc lnpop post peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed if democracy==0 & ndlegxneighall~=. & ndlegxagower~=. &ndlegxneighall_b_autocs~=. & ndlegxneighall_autocs~=., nolog vce(cluster ccode)
setx ndlegxagower 0.165 ndlegele 1 autoc_gower 0.165 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.232 ndlegele 1 autoc_gower 0.232 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
**MODEL 3: ndlegele=0->1
*autoc_gower @ 25th percentile
setx ndlegxagower 0 ndlegele 0 autoc_gower .114 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.114 ndlegele 1 autoc_gower .114 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
* autoc_gower @ 50th percentile
setx ndlegxagower 0 ndlegele 0 autoc_gower .175 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.175 ndlegele 1 autoc_gower .175 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
*CHANGES HERE
setx ndlegxagower 0 ndlegele 0 autoc_gower .201 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.201 ndlegele 1 autoc_gower .201 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
* autoc_gower @ 75th percentile
setx ndlegxagower 0 ndlegele 0 autoc_gower .211 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.211 ndlegele 1 autoc_gower .211 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
* autoc_gower @ 90th percentile
setx ndlegxagower 0 ndlegele 0 autoc_gower .256 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.256 ndlegele 1 autoc_gower .256 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
* autoc_gower @ 95th percentile
setx ndlegxagower 0 ndlegele 0 autoc_gower .263 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
setx ndlegxagower 0.263 ndlegele 1 autoc_gower .263 (post) median (neighbor_cg_democracy lnlgdppc lnpop peaceyrs_onset peaceyrs_onset_squared peaceyrs_onset_cubed) mean
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11
